Module builder

Module builder 

Structs

DevSig
Device-bound signature verifier instance holding required configuration and state.
DevSigBuilder
A typestate builder for DevSig.
Missing
Marker type for a missing dependency in the builder.