Module builder
authkestra_
devsig
0.3.3
Module builder
Module Items
Structs
In crate authkestra_
devsig
authkestra_devsig
Module
builder
Structs

DevSig
Device-bound signature verifier instance holding required configuration and state.
DevSig
Builder
A typestate builder for
DevSig
.
Missing
Marker type for a missing dependency in the builder.