pub struct SignedRequest<'a> {
pub signature: Option<&'a str>,
pub attestation: Option<&'a str>,
pub method: &'a str,
pub path: &'a str,
pub query: Option<&'a str>,
pub body: Option<&'a [u8]>,
}Expand description
The two credential headers plus the request facts needed to check request binding.
Fields
signature: Option<&'a str>Compact JWS from X-Signature.
attestation: Option<&'a str>Compact JWS from X-Attestation.
method: &'a strUppercase HTTP method, e.g. "POST".
path: &'a strRequest path, percent-encoded, excluding the query string.
query: Option<&'a str>Raw query string (no leading ?), if the request has one.
body: Option<&'a [u8]>Raw request body bytes, if the request has a body.